Basic Guides
************

This section allows getting a basic understanding for developing test scenarios and setups with balder. This information
should be sufficient to get started with Balder. You learn all key concepts here. If you want to get a deeper
understanding how balder is implemented internally or if you have some specific questions about some of these topics,
please take a look at the `Reference Guides <../deeper>`_.

.. toctree::
    :maxdepth: 2
    :caption: Basic Guides


    execution_mechanism.rst
    scenarios.rst
    setups.rst
    devices.rst
    features.rst
    vdevices.rst
    fixtures.rst
    connections.rst
    configuration.rst
    balderhub.rst
